@@ -45,21 +45,21 @@ d <- function(x, file = "",
           x1 <- x[i]
           ifelse(is.integer(x1) & (opts[1]==1),
                  if (is.na(x1) & (opts[7]==1)) {
-                   paste0(names(x1), " = NA_integer_")
+                   paste0("'", names(x1), "' = NA_integer_")
                  } else {
-                 paste0(names(x1), " = ", x1, "L")
+                 paste0("'", names(x1), "' = ", x1, "L")
                    }, 
                  if (is.na(x1) & (opts[7]==1)) {
                    paste0(names(x1), " = NA_real_")
                  } else {
-                 paste0(names(x1), " = ", format(x1, digits = 17, trim = TRUE))
+                 paste0("'", names(x1), "' = ", format(x1, digits = 17, trim = TRUE))
                  }
           )
           }
         ), 
         collapse=collapse), ")", sep="", file = file)
       } else {
-        cat("c(", paste0(names(x), " = '", 
+        cat("c(", paste0("'", names(x), "' = '", 
                          x, "'", collapse=collapse), ")", sep="", file = file)
       }
     }
